@@ -1005,54 +1005,54 @@ _dcct_pvs = [
 ]
 
 _ict_pvs = [
-    ['TB-02:DI-ICT:SampleTrg-Sel', 0, 0.0],
-    ['TB-02:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
-    ['TB-02:DI-ICT:SampleCnt-SP', 200, 0.0],
-    ['TB-02:DI-ICT:Imped-Sel', 0, 0.0],
-    ['TB-02:DI-ICT:Aperture-SP', 1, 0.0],
-    ['TB-02:DI-ICT:SampleRate-SP', 1000000, 0.0],
-    ['TB-02:DI-ICT:BCMRange-SP', 8, 0.0],
-    ['TB-02:DI-ICT:Range-Sel', 0, 0.0],
-    ['TB-02:DI-ICT:CalEnbl-Sel', 0, 0.0],
-    ['TB-02:DI-ICT:CalCharge-Sel', 0, 0.0],
-    ['TB-02:DI-ICT:Threshold-SP', 0.1, 0.0],
-    ['TB-02:DI-ICT:HFReject-Sel', 1, 0.0],
-    ['TB-04:DI-ICT:SampleTrg-Sel', 0, 0.0],
-    ['TB-04:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
-    ['TB-04:DI-ICT:SampleCnt-SP', 200, 0.0],
-    ['TB-04:DI-ICT:Imped-Sel', 0, 0.0],
-    ['TB-04:DI-ICT:Aperture-SP', 1, 0.0],
-    ['TB-04:DI-ICT:SampleRate-SP', 1000000, 0.0],
-    ['TB-04:DI-ICT:BCMRange-SP', 8, 0.0],
-    ['TB-04:DI-ICT:Range-Sel', 0, 0.0],
-    ['TB-04:DI-ICT:CalEnbl-Sel', 0, 0.0],
-    ['TB-04:DI-ICT:CalCharge-Sel', 0, 0.0],
-    ['TB-04:DI-ICT:Threshold-SP', 0.1, 0.0],
-    ['TB-04:DI-ICT:HFReject-Sel', 1, 0.0],
-    ['TS-01:DI-ICT:SampleTrg-Sel', 0, 0.0],
-    ['TS-01:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
-    ['TS-01:DI-ICT:SampleCnt-SP', 200, 0.0],
-    ['TS-01:DI-ICT:Imped-Sel', 0, 0.0],
-    ['TS-01:DI-ICT:Aperture-SP', 1, 0.0],
-    ['TS-01:DI-ICT:SampleRate-SP', 1000000, 0.0],
-    ['TS-01:DI-ICT:BCMRange-SP', 8, 0.0],
-    ['TS-01:DI-ICT:Range-Sel', 0, 0.0],
-    ['TS-01:DI-ICT:CalEnbl-Sel', 0, 0.0],
-    ['TS-01:DI-ICT:CalCharge-Sel', 0, 0.0],
-    ['TS-01:DI-ICT:Threshold-SP', 0.1, 0.0],
-    ['TS-01:DI-ICT:HFReject-Sel', 1, 0.0],
-    ['TS-04:DI-ICT:SampleTrg-Sel', 0, 0.0],
-    ['TS-04:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
-    ['TS-04:DI-ICT:SampleCnt-SP', 200, 0.0],
-    ['TS-04:DI-ICT:Imped-Sel', 0, 0.0],
-    ['TS-04:DI-ICT:Aperture-SP', 1, 0.0],
-    ['TS-04:DI-ICT:SampleRate-SP', 1000000, 0.0],
-    ['TS-04:DI-ICT:BCMRange-SP', 8, 0.0],
-    ['TS-04:DI-ICT:Range-Sel', 0, 0.0],
-    ['TS-04:DI-ICT:CalEnbl-Sel', 0, 0.0],
-    ['TS-04:DI-ICT:CalCharge-Sel', 0, 0.0],
-    ['TS-04:DI-ICT:Threshold-SP', 0.1, 0.0],
-    ['TS-04:DI-ICT:HFReject-Sel', 1, 0.0],
+    # ['TB-02:DI-ICT:SampleTrg-Sel', 0, 0.0],
+    # ['TB-02:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
+    # ['TB-02:DI-ICT:SampleCnt-SP', 200, 0.0],
+    # ['TB-02:DI-ICT:Imped-Sel', 0, 0.0],
+    # ['TB-02:DI-ICT:Aperture-SP', 1, 0.0],
+    # ['TB-02:DI-ICT:SampleRate-SP', 1000000, 0.0],
+    # ['TB-02:DI-ICT:BCMRange-SP', 8, 0.0],
+    # ['TB-02:DI-ICT:Range-Sel', 0, 0.0],
+    # ['TB-02:DI-ICT:CalEnbl-Sel', 0, 0.0],
+    # ['TB-02:DI-ICT:CalCharge-Sel', 0, 0.0],
+    # ['TB-02:DI-ICT:Threshold-SP', 0.1, 0.0],
+    # ['TB-02:DI-ICT:HFReject-Sel', 1, 0.0],
+    # ['TB-04:DI-ICT:SampleTrg-Sel', 0, 0.0],
+    # ['TB-04:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
+    # ['TB-04:DI-ICT:SampleCnt-SP', 200, 0.0],
+    # ['TB-04:DI-ICT:Imped-Sel', 0, 0.0],
+    # ['TB-04:DI-ICT:Aperture-SP', 1, 0.0],
+    # ['TB-04:DI-ICT:SampleRate-SP', 1000000, 0.0],
+    # ['TB-04:DI-ICT:BCMRange-SP', 8, 0.0],
+    # ['TB-04:DI-ICT:Range-Sel', 0, 0.0],
+    # ['TB-04:DI-ICT:CalEnbl-Sel', 0, 0.0],
+    # ['TB-04:DI-ICT:CalCharge-Sel', 0, 0.0],
+    # ['TB-04:DI-ICT:Threshold-SP', 0.1, 0.0],
+    # ['TB-04:DI-ICT:HFReject-Sel', 1, 0.0],
+    # ['TS-01:DI-ICT:SampleTrg-Sel', 0, 0.0],
+    # ['TS-01:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
+    # ['TS-01:DI-ICT:SampleCnt-SP', 200, 0.0],
+    # ['TS-01:DI-ICT:Imped-Sel', 0, 0.0],
+    # ['TS-01:DI-ICT:Aperture-SP', 1, 0.0],
+    # ['TS-01:DI-ICT:SampleRate-SP', 1000000, 0.0],
+    # ['TS-01:DI-ICT:BCMRange-SP', 8, 0.0],
+    # ['TS-01:DI-ICT:Range-Sel', 0, 0.0],
+    # ['TS-01:DI-ICT:CalEnbl-Sel', 0, 0.0],
+    # ['TS-01:DI-ICT:CalCharge-Sel', 0, 0.0],
+    # ['TS-01:DI-ICT:Threshold-SP', 0.1, 0.0],
+    # ['TS-01:DI-ICT:HFReject-Sel', 1, 0.0],
+    # ['TS-04:DI-ICT:SampleTrg-Sel', 0, 0.0],
+    # ['TS-04:DI-ICT:2ndReadDly-SP', 0.016667, 0.0],
+    # ['TS-04:DI-ICT:SampleCnt-SP', 200, 0.0],
+    # ['TS-04:DI-ICT:Imped-Sel', 0, 0.0],
+    # ['TS-04:DI-ICT:Aperture-SP', 1, 0.0],
+    # ['TS-04:DI-ICT:SampleRate-SP', 1000000, 0.0],
+    # ['TS-04:DI-ICT:BCMRange-SP', 8, 0.0],
+    # ['TS-04:DI-ICT:Range-Sel', 0, 0.0],
+    # ['TS-04:DI-ICT:CalEnbl-Sel', 0, 0.0],
+    # ['TS-04:DI-ICT:CalCharge-Sel', 0, 0.0],
+    # ['TS-04:DI-ICT:Threshold-SP', 0.1, 0.0],
+    # ['TS-04:DI-ICT:HFReject-Sel', 1, 0.0],
 ]
 
 _slit_pvs = [
