@@ -11,7 +11,8 @@ from .energy import Energy
 from .fofb import FOFBCtrlDCC, BPMDCC, FOFBCtrlRef, FamFOFBControllers, \
     FamFastCorrs, HLFOFB
 from .ict import ICT, TranspEff
-from .ids import IDCorrectors, APU, APUFeedForward
+from .ids import IDCorrectors, APU, EPU, APUFeedForward
+from .injctrl import InjCtrl
 from .injsys import ASPUStandbyHandler, BOPSRampStandbyHandler, \
     BORFRampStandbyHandler, InjBOStandbyHandler, InjSysStandbyHandler, \
     LILLRFStandbyHandler, InjSysPUModeHandler
@@ -30,8 +31,9 @@ from .sofb import SOFB
 from .syncd import DevicesSync
 from .timing import EVG, Event, Trigger, HLTiming
 from .tune import TuneFrac, TuneProc, Tune, TuneCorr
+from .dvf import DVF
 
-del device, bpm, dcct, egun, ict, lillrf, modltr,
-del pwrsupply, posang, psconv, pssofb, rf, injsys
+del device, bpm, dcct, egun, ict, lillrf, modltr
+del pwrsupply, posang, psconv, pssofb, rf, injsys, injctrl
 del screen, tune, sofb, timing, syncd, energy
-del ids, currinfo, bbb, machshift
+del ids, currinfo, bbb, machshift, dvf
