@@ -7,6 +7,7 @@ from functools import partial as _part
 import numpy as _np
 
 from ..pwrsupply.psctrl.pscstatus import PSCStatus as _PSCStatus
+from ..injctrl.csdev import Const as _InjConst
 from ..callbacks import Callback as _Callback
 
 from .device import Device as _Device, Devices as _Devices, \
@@ -42,16 +43,21 @@ class EGBias(_Device):
         super().__init__(devname, properties=EGBias._properties)
 
     @property
-    def voltage(self):
+    def voltage_mon(self):
         """."""
         return self['voltinsoft']
 
+    @property
+    def voltage(self):
+        """."""
+        return self['voltoutsoft']
+
     @voltage.setter
     def voltage(self, value):
         self['voltoutsoft'] = value
 
     @property
-    def current(self):
+    def current_mon(self):
         """."""
         return self['currentinsoft']
 
@@ -74,7 +80,7 @@ class EGBias(_Device):
         self.voltage = value
         nrp = int(timeout / 0.1)
         for _ in range(nrp):
-            if abs(self.voltage - value) < tol:
+            if abs(self.voltage_mon - value) < tol:
                 return True
             _time.sleep(0.1)
         print('timed out waiting for EGBias voltage to reach ',
@@ -110,15 +116,20 @@ class EGFilament(_Device):
         super().__init__(devname, properties=EGFilament._properties)
 
     @property
-    def voltage(self):
+    def voltage_mon(self):
         """."""
         return self['voltinsoft']
 
     @property
-    def current(self):
+    def current_mon(self):
         """."""
         return self['currentinsoft']
 
+    @property
+    def current(self):
+        """."""
+        return self['currentoutsoft']
+
     @current.setter
     def current(self, value):
         """."""
@@ -142,7 +153,7 @@ class EGFilament(_Device):
         """Wait current to reach value with tolerance 'tol'."""
         _t0 = _time.time()
         while _time.time() - _t0 < timeout:
-            if abs(self.current - value) < tol:
+            if abs(self.current_mon - value) < tol:
                 return True
             _time.sleep(0.1)
         return False
@@ -179,20 +190,30 @@ class EGHVPS(_Device):
         super().__init__(devname, properties=EGHVPS._properties)
 
     @property
-    def current(self):
+    def current_mon(self):
         """."""
         return self['currentinsoft']
 
+    @property
+    def current(self):
+        """."""
+        return self['currentoutsoft']
+
     @current.setter
     def current(self, value):
         """."""
         self['currentoutsoft'] = value
 
     @property
-    def voltage(self):
+    def voltage_mon(self):
         """."""
         return self['voltinsoft']
 
+    @property
+    def voltage(self):
+        """."""
+        return self['voltoutsoft']
+
     @voltage.setter
     def voltage(self, value):
         self['voltoutsoft'] = value
@@ -234,7 +255,7 @@ class EGHVPS(_Device):
         """Wait voltage to reach value with tolerance 'tol'."""
         _t0 = _time.time()
         while _time.time() - _t0 < timeout:
-            if abs(self.voltage - value) < tol:
+            if abs(self.voltage_mon - value) < tol:
                 return True
             _time.sleep(0.1)
         return False
@@ -243,7 +264,7 @@ class EGHVPS(_Device):
         """Wait current setpoint to reach value with tolerance 'tol'."""
         _t0 = _time.time()
         while _time.time() - _t0 < timeout:
-            if abs(self['currentoutsoft'] - value) < tol:
+            if abs(self.current_mon - value) < tol:
                 return True
             _time.sleep(0.1)
         return False
@@ -368,10 +389,15 @@ class EGPulsePS(_Device):
         self['multiswitch'] = value
 
     @property
-    def power(self):
-        """Power."""
+    def power_mon(self):
+        """Power monitor."""
         return self['powerinsoft']
 
+    @property
+    def power(self):
+        """Power readback."""
+        return self['poweroutsoft']
+
     @power.setter
     def power(self, value):
         self['poweroutsoft'] = value
@@ -445,17 +471,17 @@ class EGun(_Devices, _Callback):
     """EGun device."""
 
     DEF_TIMEOUT = 10  # [s]
-    BIAS_MULTI_BUNCH = -56.0  # [V]
-    BIAS_SINGLE_BUNCH = -100.0  # [V]
+    BIAS_MULTI_BUNCH = _InjConst.BIAS_MULTI_BUNCH
+    BIAS_SINGLE_BUNCH = _InjConst.BIAS_SINGLE_BUNCH
     BIAS_TOLERANCE = 1.0  # [V]
-    HV_OPVALUE = 90.0  # [kV]
+    HV_OPVALUE = _InjConst.HV_OPVALUE
     HV_TOLERANCE = 1.0  # [kV]
     HV_LEAKCURR_OPVALUE = 0.015  # [mA]
     HV_MAXVALUE = 90.0  # [kV]
     HV_RAMPUP_NRPTS = 15
     HV_RAMPDN_NRPTS = 6
     HV_RAMP_DURATION = 70  # [s]
-    FILACURR_OPVALUE = 1.39  # [A]
+    FILACURR_OPVALUE = _InjConst.FILACURR_OPVALUE
     FILACURR_TOLERANCE = 0.20  # [A]
     FILACURR_MAXVALUE = 1.42  # [A]
     FILACURR_RAMP_NRPTS = 10
@@ -534,7 +560,7 @@ class EGun(_Devices, _Callback):
         self._abort_chg_type.clear()
         self._update_status('Switching EGun mode to SingleBunch...')
 
-        if not self.connected:
+        if not self.wait_for_connection(1):
             self._update_status('ERR:EGun device not connected. Aborted.')
             return False
 
@@ -568,7 +594,7 @@ class EGun(_Devices, _Callback):
         self._abort_chg_type.clear()
         self._update_status('Switching EGun mode to MultiBunch...')
 
-        if not self.connected:
+        if not self.wait_for_connection(1):
             self._update_status('ERR:EGun device not connected. Aborted.')
             return False
 
@@ -598,7 +624,7 @@ class EGun(_Devices, _Callback):
     @property
     def is_single_bunch(self):
         """Is configured to single bunch mode."""
-        if not self.connected:
+        if not self.wait_for_connection(1):
             return False
         sts = not self.pulse.multi_bunch_switch
         sts &= not self.pulse.multi_bunch_mode
@@ -612,7 +638,7 @@ class EGun(_Devices, _Callback):
     @property
     def is_multi_bunch(self):
         """Is configured to multi bunch mode."""
-        if not self.connected:
+        if not self.wait_for_connection(1):
             return False
         sts = not self.pulse.single_bunch_switch
         sts &= not self.pulse.single_bunch_mode
@@ -645,10 +671,10 @@ class EGun(_Devices, _Callback):
     @property
     def is_hv_on(self):
         """Indicate whether high voltage is on and in operational value."""
-        if not self.hvps.connected:
+        if not self.hvps.wait_for_connection(1):
             return False
         is_on = self.hvps.is_on()
-        is_op = abs(self.hvps.voltage - self._hv_opval) < self._hv_tol
+        is_op = abs(self.hvps.voltage_mon - self._hv_opval) < self._hv_tol
         return is_on and is_op
 
     def set_hv_voltage(self, value=None, duration=None, timeout=DEF_TIMEOUT):
@@ -706,7 +732,7 @@ class EGun(_Devices, _Callback):
             return False
 
         # if value is lower, do a ramp down
-        if value < self.hvps.voltage:
+        if value < self.hvps.voltage_mon:
             nrpts = EGun.HV_RAMPDN_NRPTS
             power = 1
         else:  # else, do a ramp up
@@ -715,7 +741,7 @@ class EGun(_Devices, _Callback):
         duration = duration if duration is not None else EGun.HV_RAMP_DURATION
         max_value = EGun.HV_MAXVALUE
         ydata = self._get_ramp(
-            self.hvps.voltage, value, nrpts, max_value, power)
+            self.hvps.voltage_mon, value, nrpts, max_value, power)
         t_inter = duration / (nrpts-1)
 
         self._update_status(f'Starting HVPS ramp to {value:.3f}kV.')
@@ -738,7 +764,7 @@ class EGun(_Devices, _Callback):
                     self._update_status(
                         'ERR:MPS or LI Status not ok. Aborted.')
                     return False
-                if abs(self.hvps.voltage - volt) < self._hv_tol:
+                if abs(self.hvps.voltage_mon - volt) < self._hv_tol:
                     break
                 _time.sleep(0.1)
             else:
@@ -761,7 +787,7 @@ class EGun(_Devices, _Callback):
     @property
     def is_fila_on(self):
         """Indicate whether filament is on and in operational current."""
-        if not self.fila.connected:
+        if not self.fila.wait_for_connection(1):
             return False
         is_on = self.fila.is_on()
         is_op_sp = abs(self.fila['currentoutsoft']-self._filacurr_opval) < 1e-4
@@ -799,7 +825,7 @@ class EGun(_Devices, _Callback):
             return False
 
         # elif value is lower, do only one setpoint
-        if value < self.fila.current:
+        if value < self.fila.current_mon:
             self._update_status(f'Setting current to {value:.3f}A...')
             self.fila.current = value
             if self.fila.wait_current(value, self._filacurr_tol):
@@ -817,7 +843,7 @@ class EGun(_Devices, _Callback):
         duration = EGun.FILACURR_RAMP_DURATION
         nrpts = EGun.FILACURR_RAMP_NRPTS
         max_value = EGun.FILACURR_MAXVALUE
-        ydata = self._get_ramp(self.fila.current, value, nrpts, max_value)
+        ydata = self._get_ramp(self.fila.current_mon, value, nrpts, max_value)
         t_inter = duration / (nrpts-1)
         total_steps_duration = (len(ydata)-1)*t_inter
 
@@ -900,7 +926,7 @@ class EGun(_Devices, _Callback):
 
     def _check_status_ok(self):
         """Check if interlock signals are ok."""
-        if not self.connected:
+        if not self.wait_for_connection(1):
             return False
         isok = [self.mps_ccg[ppty] == 0 for ppty in self.mps_ccg.properties]
         allok = all(isok)
