@@ -1,6 +1,5 @@
 """FOFB devices."""
 
-import time as _time
 import numpy as _np
 
 from mathphys.functions import get_namedtuple as _get_namedtuple
@@ -30,6 +29,11 @@ class FOFBCtrlRef(_Device, _FOFBCtrlBase):
 
     _properties = (
         'RefOrb-SP', 'RefOrb-RB',
+        'MaxOrbDistortion-SP', 'MaxOrbDistortion-RB',
+        'MaxOrbDistortionEnbl-Sel', 'MaxOrbDistortionEnbl-Sts',
+        'MinBPMCnt-SP', 'MinBPMCnt-RB',
+        'MinBPMCntEnbl-Sel', 'MinBPMCntEnbl-Sts',
+        'LoopIntlk-Mon', 'LoopIntlkReset-Cmd',
     )
 
     def __init__(self, devname):
@@ -116,6 +120,52 @@ class FOFBCtrlRef(_Device, _FOFBCtrlBase):
             return False
         return True
 
+    @property
+    def max_orb_distortion(self):
+        """Orbit distortion threshold [nm]."""
+        return self['MaxOrbDistortion-RB']
+
+    @max_orb_distortion.setter
+    def max_orb_distortion(self, value):
+        self['MaxOrbDistortion-SP'] = value
+
+    @property
+    def max_orb_distortion_enbl(self):
+        """Orbit distortion above threshold detection enable status."""
+        return self['MaxOrbDistortionEnbl-Sts']
+
+    @max_orb_distortion_enbl.setter
+    def max_orb_distortion_enbl(self, value):
+        self['MaxOrbDistortionEnbl-Sel'] = value
+
+    @property
+    def min_bpm_count(self):
+        """Minimum BPM packet count."""
+        return self['MinBPMCnt-RB']
+
+    @min_bpm_count.setter
+    def min_bpm_count(self, value):
+        self['MinBPMCnt-SP'] = value
+
+    @property
+    def min_bpm_count_enbl(self):
+        """Packet loss detection enable status."""
+        return self['MinBPMCntEnbl-Sts']
+
+    @min_bpm_count_enbl.setter
+    def min_bpm_count_enbl(self, value):
+        self['MinBPMCntEnbl-Sel'] = value
+
+    @property
+    def interlock(self):
+        """Interlock status."""
+        return self['LoopIntlk-Mon']
+
+    def cmd_reset(self):
+        """Reset interlocks."""
+        self['LoopIntlkReset-Cmd'] = 1
+        return True
+
 
 class _DCCDevice(_ProptyDevice):
     """FOFB Diamond communication controller device."""
@@ -124,8 +174,6 @@ class _DCCDevice(_ProptyDevice):
     DEF_FMC_BPMCNT = NR_BPM
     DEF_P2P_BPMCNT = 8
 
-    _sync_sleep = 1.0  # [s]
-
     _properties = (
         'BPMId-SP', 'BPMId-RB', 'BPMCnt-Mon',
         'CCEnable-SP', 'CCEnable-RB',
@@ -225,8 +273,9 @@ class BPMDCC(_DCCDevice):
 
     def __init__(self, devname):
         """Init."""
-        if not _BPMSearch.is_valid_devname(devname):
-            raise NotImplementedError(devname)
+        # Temporarily remove this check to control new 10SB BPMs
+        # if not _BPMSearch.is_valid_devname(devname):
+        #     raise NotImplementedError(devname)
         super().__init__(devname, 'DCCP2P')
 
 
@@ -239,6 +288,13 @@ class FamFOFBControllers(_Devices):
     DEF_BPMTRIG_RCVIN = 5
     BPM_TRIGS_IDS = [1, 2, 20]
     FOFBCTRL_BPMID_OFFSET = 480
+    BPM_DCC_PAIRS = {
+        'M1': 'M2',
+        'C1-1': 'C1-2',
+        'C2': 'C3-1',
+        'C3-2': 'C4',
+    }
+    BPM_DCC_PAIRS.update({bd: bu for bu, bd in BPM_DCC_PAIRS.items()})
 
     def __init__(self):
         """Init."""
@@ -265,6 +321,10 @@ class FamFOFBControllers(_Devices):
             for trig in self.BPM_TRIGS_IDS:
                 trigname = bpm + ':TRIGGER' + str(trig)
                 self._bpm_trgs[trigname] = BPMLogicalTrigger(bpm, trig)
+        bpm2dsbl = ['SI-10SB:DI-BPM-1', 'SI-10SB:DI-BPM-2']
+        self._bpmdcc2dsbl = dict()
+        for bpm in bpm2dsbl:
+            self._bpmdcc2dsbl[bpm] = BPMDCC(bpm)
         # fofb event
         self._evt_fofb = Event('FOFBS')
 
@@ -277,6 +337,31 @@ class FamFOFBControllers(_Devices):
 
         super().__init__('SI-Glob:BS-FOFB', devices)
 
+    @property
+    def ctrlrefdevs(self):
+        """FOFBCtrlRef device list."""
+        return self._ctl_refs
+
+    @property
+    def ctrldccdevs(self):
+        """FOFBCtrlDCC device list."""
+        return self._ctl_dccs
+
+    @property
+    def bpmdccdevs(self):
+        """BPMDCC device list."""
+        return self._bpm_dccs
+
+    @property
+    def bpmtrigdevs(self):
+        """BPMLogicalTrigger device list."""
+        return self._bpm_trgs
+
+    @property
+    def fofbevtdev(self):
+        """FOFBS Event device."""
+        return self._evt_fofb
+
     def set_reforb(self, value):
         """Set RefOrb for all FOFB controllers."""
         for ctrl in self._ctl_refs.values():
@@ -323,6 +408,113 @@ class FamFOFBControllers(_Devices):
                 return False
         return True
 
+    @property
+    def max_orb_distortion(self):
+        """Orbit distortion threshold [nm].
+
+        Returns:
+            threshold (numpy.ndarray, 20):
+                orbit distortion threshold for each FOFB controller.
+        """
+        devs = self._ctl_refs.values()
+        return _np.array([d.max_orb_distortion for d in devs])
+
+    def set_max_orb_distortion(self, value, timeout=DEF_TIMEOUT):
+        """Set orbit distortion threshold [nm]."""
+        devs = list(self._ctl_refs.values())
+        self._set_devices_propty(devs, 'MaxOrbDistortion-SP', value)
+        if not self._wait_devices_propty(
+                devs, 'MaxOrbDistortion-RB', value, timeout=timeout):
+            return False
+        return True
+
+    @property
+    def max_orb_distortion_enbl(self):
+        """Orbit distortion above threshold detection enable status.
+
+        Returns:
+            status (numpy.ndarray, 20):
+                orbit distortion detection status for each FOFB controller.
+        """
+        devs = self._ctl_refs.values()
+        return _np.array([d.max_orb_distortion_enbl for d in devs])
+
+    def set_max_orb_distortion_enbl(self, value, timeout=DEF_TIMEOUT):
+        """Set orbit distortion above threshold detection enable status."""
+        devs = list(self._ctl_refs.values())
+        self._set_devices_propty(devs, 'MaxOrbDistortionEnbl-Sel', value)
+        if not self._wait_devices_propty(
+                devs, 'MaxOrbDistortionEnbl-Sts', value, timeout=timeout):
+            return False
+        return True
+
+    @property
+    def min_bpm_count(self):
+        """Minimum BPM packet count.
+
+        Returns:
+            minimum (numpy.ndarray, 20):
+                minimum BPM packet count for each FOFB controller.
+        """
+        devs = self._ctl_refs.values()
+        return _np.array([d.min_bpm_count for d in devs])
+
+    def set_min_bpm_count(self, value, timeout=DEF_TIMEOUT):
+        """Set minimum BPM packet count."""
+        devs = list(self._ctl_refs.values())
+        self._set_devices_propty(devs, 'MinBPMCnt-SP', value)
+        if not self._wait_devices_propty(
+                devs, 'MinBPMCnt-RB', value, timeout=timeout):
+            return False
+        return True
+
+    @property
+    def min_bpm_count_enbl(self):
+        """Packet loss detection enable status.
+
+        Returns:
+            status (numpy.ndarray, 20):
+                packet loss detection status for each FOFB controller.
+        """
+        devs = self._ctl_refs.values()
+        return _np.array([d.min_bpm_count_enbl for d in devs])
+
+    def set_min_bpm_count_enbl(self, value, timeout=DEF_TIMEOUT):
+        """Set orbit distortion above threshold detection enable status."""
+        devs = list(self._ctl_refs.values())
+        self._set_devices_propty(devs, 'MinBPMCntEnbl-Sel', value)
+        if not self._wait_devices_propty(
+                devs, 'MinBPMCntEnbl-Sts', value, timeout=timeout):
+            return False
+        return True
+
+    @property
+    def interlock(self):
+        """Interlock status.
+
+        Returns:
+            status (numpy.ndarray, 20):
+                interlock status for each FOFB controller.
+        """
+        devs = self._ctl_refs.values()
+        return _np.array([d.interlock for d in devs])
+
+    @property
+    def interlock_ok(self):
+        """Interlock ok status."""
+        if not self.connected:
+            return False
+        return _np.all(self.interlock == 0)
+
+    def cmd_reset(self, timeout=DEF_TIMEOUT):
+        """Send reset interlock command for all FOFB controllers."""
+        devs = list(self._ctl_refs.values())
+        self._set_devices_propty(devs, 'LoopIntlkReset-Cmd', 1)
+        if not self._wait_devices_propty(
+                devs, 'LoopIntlk-Mon', 0, timeout=timeout):
+            return False
+        return True
+
     @property
     def bpm_id(self):
         """Return DCC BPMIds."""
@@ -407,6 +599,13 @@ class FamFOFBControllers(_Devices):
         for bpm in bpms:
             enbdccs.append(self._bpm_dccs[bpm])
 
+        # temporary solution: disable BPM DCCs that are not in FOFB network
+        dcc2dsbl = list(self._bpmdcc2dsbl.values())
+        self._set_devices_propty(dcc2dsbl, 'CCEnable-SP', 0)
+        if not self._wait_devices_propty(
+                dcc2dsbl, 'CCEnable-RB', 0, timeout=timeout/2):
+            return False
+
         self._set_devices_propty(alldccs, 'CCEnable-SP', 0)
         if not self._wait_devices_propty(
                 alldccs, 'CCEnable-RB', 0, timeout=timeout/2):
@@ -424,16 +623,32 @@ class FamFOFBControllers(_Devices):
             return False
         if bpms is None:
             bpms = self._bpmnames
+        dccfmc_bpmcount = len(self.get_dccfmc_visible_bpms(bpms))
         for dev in self._ctl_dccs.values():
             if dev.dccname != 'DCCFMC':
                 continue
-            if not dev.bpm_count == len(bpms):
+            if not dev.bpm_count == dccfmc_bpmcount:
                 return False
         for bpm in bpms:
             if not self._bpm_dccs[bpm].cc_enable == 1:
                 return False
         return True
 
+    def get_dccfmc_visible_bpms(self, bpms):
+        """Return DCCFMC visible BPMs."""
+        dccenbl = set()
+        for bpm in bpms:
+            name = _PVName(bpm)
+            nick = name.sub[2:] + ('-' + name.idx if name.idx else '')
+            nickpair = self.BPM_DCC_PAIRS[nick]
+            nps = nickpair.split('-')
+            if len(nps) == 1:
+                nps.append('')
+            pair = name.substitute(sub=name.sub[:2] + nps[0], idx=nps[1])
+            dccenbl.add(bpm)
+            dccenbl.add(pair)
+        return dccenbl
+
     @property
     def time_frame_len(self):
         """Time frame length.
@@ -861,15 +1076,20 @@ class HLFOFB(_Device):
         'LoopState-Sel', 'LoopState-Sts',
         'LoopGainH-SP', 'LoopGainH-RB', 'LoopGainH-Mon',
         'LoopGainV-SP', 'LoopGainV-RB', 'LoopGainV-Mon',
+        'LoopMaxOrbDistortion-SP', 'LoopMaxOrbDistortion-RB',
+        'LoopMaxOrbDistortionEnbl-Sel', 'LoopMaxOrbDistortionEnbl-Sts',
+        'LoopPacketLossDetecEnbl-Sel', 'LoopPacketLossDetecEnbl-Sts',
         'CorrStatus-Mon', 'CorrConfig-Cmd',
         'CorrSetPwrStateOn-Cmd', 'CorrSetOpModeManual-Cmd',
         'CorrSetAccFreezeDsbl-Cmd', 'CorrSetAccFreezeEnbl-Cmd',
         'CorrSetAccClear-Cmd', 'CorrSetCurrZero-Cmd',
         'CHAccSatMax-SP', 'CHAccSatMax-RB',
         'CVAccSatMax-SP', 'CVAccSatMax-RB',
-        'FOFBCtrlStatus-Mon', 'FOFBCtrlConfBPMId-Cmd',
-        'FOFBCtrlSyncNet-Cmd', 'FOFBCtrlSyncRefOrb-Cmd',
-        'FOFBCtrlConfTFrameLen-Cmd', 'FOFBCtrlConfBPMLogTrg-Cmd',
+        'CtrlrStatus-Mon', 'CtrlrConfBPMId-Cmd',
+        'CtrlrSyncNet-Cmd', 'CtrlrSyncRefOrb-Cmd',
+        'CtrlrSyncTFrameLen-Cmd', 'CtrlrConfBPMLogTrg-Cmd',
+        'CtrlrSyncMaxOrbDist-Cmd', 'CtrlrSyncPacketLossDetec-Cmd',
+        'CtrlrReset-Cmd',
         'KickBufferSize-SP', 'KickBufferSize-RB', 'KickBufferSize-Mon',
         'KickCH-Mon', 'KickCV-Mon',
         'RefOrbX-SP', 'RefOrbX-RB', 'RefOrbY-SP', 'RefOrbY-RB',
@@ -950,6 +1170,33 @@ class HLFOFB(_Device):
         """Implemented vertical loop gain."""
         return self['LoopGainV-Mon']
 
+    @property
+    def loop_max_orb_dist(self):
+        """Loop orbit distortion threshold."""
+        return self['LoopMaxOrbDistortion-RB']
+
+    @loop_max_orb_dist.setter
+    def loop_max_orb_dist(self, value):
+        self['LoopMaxOrbDistortion-SP'] = value
+
+    @property
+    def loop_max_orb_dist_enbl(self):
+        """Loop orbit distortion detection enable status."""
+        return self['LoopMaxOrbDistortionEnbl-Sts']
+
+    @loop_max_orb_dist_enbl.setter
+    def loop_max_orb_dist_enbl(self, value):
+        self['LoopMaxOrbDistortionEnbl-Sel'] = value
+
+    @property
+    def loop_packloss_detec_enbl(self):
+        """Loop packet loss detection enable status."""
+        return self['LoopPacketLossDetecEnbl-Sts']
+
+    @loop_packloss_detec_enbl.setter
+    def loop_packloss_detec_enbl(self, value):
+        self['LoopPacketLossDetecEnbl-Sel'] = value
+
     @property
     def corr_status(self):
         """Corrector status."""
@@ -1011,31 +1258,46 @@ class HLFOFB(_Device):
     @property
     def fofbctrl_status(self):
         """FOFB controller status."""
-        return self['FOFBCtrlStatus-Mon']
+        return self['CtrlrStatus-Mon']
 
     def cmd_fofbctrl_conf_bpmid(self):
         """Command to configure all FOFB DCC BPMIds."""
-        self['FOFBCtrlConfBPMId-Cmd'] = 1
+        self['CtrlrConfBPMId-Cmd'] = 1
         return True
 
     def cmd_fofbctrl_syncnet(self):
         """Command to sync FOFB controller net."""
-        self['FOFBCtrlSyncNet-Cmd'] = 1
+        self['CtrlrSyncNet-Cmd'] = 1
         return True
 
     def cmd_fofbctrl_syncreforb(self):
         """Command to sync FOFB controller RefOrb."""
-        self['FOFBCtrlSyncRefOrb-Cmd'] = 1
+        self['CtrlrSyncRefOrb-Cmd'] = 1
         return True
 
-    def cmd_fofbctrl_conf_timeframelen(self):
-        """Command to configure all FOFB controller TimeFrameLen."""
-        self['FOFBCtrlConfTFrameLen-Cmd'] = 1
+    def cmd_fofbctrl_sync_timeframelen(self):
+        """Command to sync all FOFB controller TimeFrameLen."""
+        self['CtrlrSyncTFrameLen-Cmd'] = 1
         return True
 
     def cmd_fofbctrl_conf_bpmlogtrig(self):
         """Command to configure all BPM logical triggers related to FOFB."""
-        self['FOFBCtrlConfBPMLogTrg-Cmd'] = 1
+        self['CtrlrConfBPMLogTrg-Cmd'] = 1
+        return True
+
+    def cmd_fofbctrl_sync_maxorbdist(self):
+        """Command to sync all FOFB controllers orbit distortion detection."""
+        self['CtrlrSyncMaxOrbDist-Cmd'] = 1
+        return True
+
+    def cmd_fofbctrl_sync_packlossdet(self):
+        """Command to sync all FOFB controllers packet loss detection."""
+        self['CtrlrSyncPacketLossDetec-Cmd'] = 1
+        return True
+
+    def cmd_fofbctrl_reset(self):
+        """Command to reset interlocks of all FOFB controllers."""
+        self['CtrlrReset-Cmd'] = 1
         return True
 
     @property
@@ -1093,7 +1355,7 @@ class HLFOFB(_Device):
     @property
     def bpmxenbl(self):
         """BPM X enable list."""
-        return self['BPMXEnblList-RB']
+        return _np.array(self['BPMXEnblList-RB'], dtype=bool)
 
     @bpmxenbl.setter
     def bpmxenbl(self, value):
@@ -1102,7 +1364,7 @@ class HLFOFB(_Device):
     @property
     def bpmyenbl(self):
         """BPM Y enable list."""
-        return self['BPMYEnblList-RB']
+        return _np.array(self['BPMYEnblList-RB'], dtype=bool)
 
     @bpmyenbl.setter
     def bpmyenbl(self, value):
@@ -1111,7 +1373,7 @@ class HLFOFB(_Device):
     @property
     def chenbl(self):
         """CH enable list."""
-        return self['CHEnblList-RB']
+        return _np.array(self['CHEnblList-RB'], dtype=bool)
 
     @chenbl.setter
     def chenbl(self, value):
@@ -1120,7 +1382,7 @@ class HLFOFB(_Device):
     @property
     def cvenbl(self):
         """CV enable list."""
-        return self['CVEnblList-RB']
+        return _np.array(self['CVEnblList-RB'], dtype=bool)
 
     @cvenbl.setter
     def cvenbl(self, value):
@@ -1129,7 +1391,7 @@ class HLFOFB(_Device):
     @property
     def rfenbl(self):
         """Use RF in RespMat calculation."""
-        return self['UseRF-Sts']
+        return bool(self['UseRF-Sts'])
 
     @rfenbl.setter
     def rfenbl(self, value):
