@@ -72,6 +72,7 @@ class TLSOFB(_Device):
         'MeasRespMatWait-SP', 'MeasRespMatWait-RB',
         'NrSingValues-Mon', 'MinSingValue-SP', 'MinSingValue-RB',
         'TrigAcqCtrl-Sel', 'TrigAcqCtrl-Sts', 'TrigAcqConfig-Cmd',
+        'SyncBPMs-Cmd',
         )
 
     _default_timeout = 10  # [s]
@@ -268,7 +269,7 @@ class TLSOFB(_Device):
     @property
     def bpmxenbl(self):
         """."""
-        return self['BPMXEnblList-RB']
+        return _np.array(self['BPMXEnblList-RB'], dtype=bool)
 
     @bpmxenbl.setter
     def bpmxenbl(self, value):
@@ -278,7 +279,7 @@ class TLSOFB(_Device):
     @property
     def bpmyenbl(self):
         """."""
-        return self['BPMYEnblList-RB']
+        return _np.array(self['BPMYEnblList-RB'], dtype=bool)
 
     @bpmyenbl.setter
     def bpmyenbl(self, value):
@@ -288,7 +289,7 @@ class TLSOFB(_Device):
     @property
     def chenbl(self):
         """."""
-        return self['CHEnblList-RB']
+        return _np.array(self['CHEnblList-RB'], dtype=bool)
 
     @chenbl.setter
     def chenbl(self, value):
@@ -298,7 +299,7 @@ class TLSOFB(_Device):
     @property
     def cvenbl(self):
         """."""
-        return self['CVEnblList-RB']
+        return _np.array(self['CVEnblList-RB'], dtype=bool)
 
     @cvenbl.setter
     def cvenbl(self, value):
@@ -567,6 +568,11 @@ class TLSOFB(_Device):
         """."""
         return self._wait('OrbStatus-Mon', 0, timeout=timeout)
 
+    def cmd_sync_bpms(self):
+        """Synchronize BPMs."""
+        self['SyncBPMs-Cmd'] = 1
+        return True
+
 
 class BOSOFB(TLSOFB):
     """SOFB Device."""
@@ -794,8 +800,8 @@ class SISOFB(BOSOFB):
     @property
     def rfenbl(self):
         """."""
-        dta = self._data
-        return self['RFEnbl-Sts'] if dta.acc_idx == dta.Rings.SI else None
+        if self._data.acc_idx == self._data.Rings.SI:
+            return bool(self['RFEnbl-Sts'])
 
     @rfenbl.setter
     def rfenbl(self, value):
