@@ -85,7 +85,7 @@ class EpicsOrbit(BaseOrbit):
         """Initialize the instance."""
         super().__init__(acc, prefix=prefix, callback=callback)
 
-        self._mode = self._csorb.SOFBMode.Offline
+        self._mode = 0  # first mode of the list
         self._sofb = None
         self._sync_with_inj = False
         self._sloworb_timeout = 0
@@ -100,25 +100,16 @@ class EpicsOrbit(BaseOrbit):
         self.smooth_orb = {'X': None, 'Y': None}
         self.smooth_sporb = {'X': None, 'Y': None, 'Sum': None}
         self.smooth_mtorb = {'X': None, 'Y': None, 'Sum': None}
-        self.offline_orbit = {
-            'X': _np.zeros(self._csorb.nr_bpms),
-            'Y': _np.zeros(self._csorb.nr_bpms)}
         self._smooth_npts = 1
         self._smooth_meth = self._csorb.SmoothMeth.Average
         self._spass_mask = [0, 0]
         self._spass_average = 1
-        self._spass_th_acqbg = None
-        self._spass_bgs = [dict() for _ in range(self._csorb.nr_bpms)]
-        self._spass_usebg = self._csorb.SPassUseBg.NotUsing
-        self._acqrate = self._csorb.MIN_SLOWORB_RATE
-        self._oldacqrate = self._acqrate
         self._acqtrignrsamplespre = 0
         self._acqtrignrsamplespost = 360
         self._acqtrignrshots = 1
         self._multiturnidx = 0
         self._mturndownsample = 1
         self._timevector = None
-        self._ring_extension = 1
         self.bpms = [BPM(name, callback) for name in self._csorb.bpm_names]
         self.timing = TimingConfig(acc, callback)
         self.new_orbit = _Event()
@@ -128,8 +119,9 @@ class EpicsOrbit(BaseOrbit):
             self._mypipes_send = []
             self._create_processes(nrprocs=16)
         self._orbit_thread = _Repeat(
-            1/self._acqrate, self._update_orbits, niter=0)
+            1/self._csorb.ACQRATE_SLOWORB, self._update_orbits, niter=0)
         self._orbit_thread.start()
+        self._thread_sync = None
         self._update_time_vector()
 
     @property
@@ -190,30 +182,20 @@ class EpicsOrbit(BaseOrbit):
             'TrigAcqConfig-Cmd': self.acq_config_bpms,
             'TrigAcqCtrl-Sel': self.set_trig_acq_control,
             'TrigAcqChan-Sel': self.set_trig_acq_channel,
-            'TrigDataChan-Sel': self.set_trig_acq_datachan,
-            'TrigAcqTrigger-Sel': self.set_trig_acq_trigger,
             'TrigAcqRepeat-Sel': self.set_trig_acq_repeat,
-            'TrigDataSel-Sel': self.set_trig_acq_datasel,
-            'TrigDataThres-SP': self.set_trig_acq_datathres,
-            'TrigDataHyst-SP': self.set_trig_acq_datahyst,
-            'TrigDataPol-Sel': self.set_trig_acq_datapol,
             'TrigNrSamplesPre-SP': _part(self.set_acq_nrsamples, ispost=False),
             'TrigNrSamplesPost-SP': _part(self.set_acq_nrsamples, ispost=True),
             'RefOrbX-SP': _part(self.set_reforb, 'X'),
             'RefOrbY-SP': _part(self.set_reforb, 'Y'),
-            'OfflineOrbX-SP': _part(self.set_offlineorb, 'X'),
-            'OfflineOrbY-SP': _part(self.set_offlineorb, 'Y'),
             'SmoothNrPts-SP': self.set_smooth_npts,
             'SmoothMethod-Sel': self.set_smooth_method,
             'SmoothReset-Cmd': self.set_smooth_reset,
             'SPassMaskSplBeg-SP': _part(self.set_spass_mask, beg=True),
             'SPassMaskSplEnd-SP': _part(self.set_spass_mask, beg=False),
-            'SPassBgCtrl-Cmd': self.set_spass_bg,
-            'SPassUseBg-Sel': self.set_spass_usebg,
             'SPassAvgNrTurns-SP': self.set_spass_average,
-            'OrbAcqRate-SP': self.set_orbit_acq_rate,
             'TrigNrShots-SP': self.set_trig_acq_nrshots,
             'PolyCalibration-Sel': self.set_poly_calibration,
+            'SyncBPMs-Cmd': self.sync_bpms,
             }
         if not self.isring:
             return dbase
@@ -265,82 +247,40 @@ class EpicsOrbit(BaseOrbit):
         """Check is mode or self._mode is in any of the Triggered modes."""
         return self.is_singlepass(mode) or self.is_multiturn(mode)
 
-    def set_ring_extension(self, val):
-        """."""
-        maval = self._csorb.MAX_RINGSZ
-        val = 1 if val < 1 else int(val)
-        val = maval if val > maval else val
-        if val == self._ring_extension:
-            return True
-        with self._lock_raw_orbs:
-            self._spass_average = 1
-            self.run_callbacks('SPassAvgNrTurns-SP', 1)
-            self.run_callbacks('SPassAvgNrTurns-RB', 1)
-            self._mturndownsample = 1
-            self.run_callbacks('MTurnDownSample-SP', 1)
-            self.run_callbacks('MTurnDownSample-RB', 1)
-            self._reset_orbs()
-            self._ring_extension = val
-            nrb = val * self._csorb.nr_bpms
-            for pln in self.offline_orbit:
-                orb = self.ref_orbs[pln]
-                if orb.size < nrb:
-                    nrep = _ceil(nrb/orb.size)
-                    orb2 = _np.tile(orb, nrep)
-                    orb = orb2[:nrb]
-                self.ref_orbs[pln] = orb
-                self.run_callbacks('RefOrb'+pln+'-RB', orb[:nrb])
-                self.run_callbacks('RefOrb'+pln+'-SP', orb[:nrb])
-                orb = self.offline_orbit[pln]
-                if orb.size < nrb:
-                    orb2 = self.ref_orbs[pln].copy()
-                    orb2[:orb.size] = orb
-                    orb = orb2
-                self.offline_orbit[pln] = orb
-                self.run_callbacks('OfflineOrb'+pln+'-RB', orb[:nrb])
-                self.run_callbacks('OfflineOrb'+pln+'-SP', orb[:nrb])
-        self._save_ref_orbits()
-        Thread(target=self._prepare_mode, daemon=True).start()
-        return True
-
     def get_orbit(self, reset=False, synced=False, timeout=1/10):
         """Return the orbit distortion."""
-        nrb = self._ring_extension * self._csorb.nr_bpms
+        nrb = self._csorb.nr_bpms
         refx = self.ref_orbs['X'][:nrb]
         refy = self.ref_orbs['Y'][:nrb]
-        if self._mode == self._csorb.SOFBMode.Offline:
-            orbx = self.offline_orbit['X'][:nrb]
-            orby = self.offline_orbit['Y'][:nrb]
-            return _np.hstack([orbx-refx, orby-refy])
 
         if reset:
             with self._lock_raw_orbs:
                 self._reset_orbs()
-            _time.sleep(self._smooth_npts/self._acqrate)
+            _time.sleep(self._smooth_npts/self._csorb.ACQRATE_SLOWORB)
 
         if self.is_multiturn():
             orbs = self.smooth_mtorb
-            raw_orbs = self.raw_mtorbs
+            raws = self.raw_mtorbs
             getorb = self._get_orbit_multiturn
         elif self.is_singlepass():
             orbs = self.smooth_sporb
-            raw_orbs = self.raw_sporbs
+            raws = self.raw_sporbs
             getorb = self._get_orbit_singlepass
         elif self.is_sloworb():
             if synced:
                 self.new_orbit.wait(timeout=timeout)
                 self.new_orbit.clear()
             orbs = self.smooth_orb
-            raw_orbs = self.raw_orbs
+            raws = self.raw_orbs
             getorb = self._get_orbit_online
 
         for _ in range(3 * self._smooth_npts):
-            isnone = orbs['X'] is None or orbs['Y'] is None
-            if isnone or len(raw_orbs['X']) < self._smooth_meth:
-                _time.sleep(1/self._acqrate)
-                continue
-            orbx, orby = getorb(orbs)
-            break
+            with self._lock_raw_orbs:
+                isempty = orbs['X'] is None or orbs['Y'] is None
+                if not isempty and len(raws['X']) >= self._smooth_npts:
+                    orbx, orby = getorb(orbs)
+                    break
+            _time.sleep(1/self._csorb.ACQRATE_SLOWORB)
         else:
             msg = 'ERR: timeout waiting orbit.'
             self._update_log(msg)
@@ -364,26 +304,6 @@ class EpicsOrbit(BaseOrbit):
         idx = self._multiturnidx
         return orbs['X'][idx, :], orbs['Y'][idx, :]
 
-    def set_offlineorb(self, plane, orb):
-        """."""
-        msg = 'Setting New Offline Orbit.'
-        self._update_log(msg)
-        _log.info(msg)
-        orb = _np.array(orb, dtype=float)
-        nrb = self._ring_extension * self._csorb.nr_bpms
-        if orb.size % self._csorb.nr_bpms:
-            msg = 'ERR: Wrong OfflineOrb Size.'
-            self._update_log(msg)
-            _log.error(msg[5:])
-            return False
-        elif orb.size < nrb:
-            orb2 = _np.zeros(nrb, dtype=float)
-            orb2[:orb.size] = orb
-            orb = orb2
-        self.offline_orbit[plane] = orb
-        self.run_callbacks('OfflineOrb'+plane+'-RB', orb[:nrb])
-        return True
-
     def set_smooth_npts(self, num):
         """."""
         self._smooth_npts = num
@@ -407,30 +327,6 @@ class EpicsOrbit(BaseOrbit):
         self.run_callbacks('SPassMaskSpl' + name + '-RB', val)
         return True
 
-    def set_spass_bg(self, val):
-        """."""
-        if val == self._csorb.SPassBgCtrl.Acquire:
-            trh = self._spass_th_acqbg
-            if trh is None or not trh.is_alive():
-                self._spass_th_acqbg = Thread(
-                    target=self._do_acquire_spass_bg, daemon=True)
-                self._spass_th_acqbg.start()
-            else:
-                msg = 'WARN: SPassBg is already being acquired.'
-                self._update_log(msg)
-                _log.warning(msg[6:])
-        elif val == self._csorb.SPassBgCtrl.Reset:
-            self.run_callbacks(
-                'SPassUseBg-Sts', self._csorb.SPassUseBg.NotUsing)
-            self._spass_bgs = [dict() for _ in range(len(self.bpms))]
-            self.run_callbacks('SPassBgSts-Mon', self._csorb.SPassBgSts.Empty)
-        else:
-            msg = 'ERR: SPassBg Control not recognized.'
-            self._update_log(msg)
-            _log.warning(msg[5:])
-            return False
-        return True
-
     def set_mturn_sync(self, val):
         """."""
         value = _csbpm.EnbldDsbld.enabled
@@ -481,51 +377,8 @@ class EpicsOrbit(BaseOrbit):
         self.run_callbacks('MTurnMaskSpl' + name + '-RB', val)
         return True
 
-    def _do_acquire_spass_bg(self):
-        """."""
-        self.run_callbacks('SPassBgSts-Mon', self._csorb.SPassBgSts.Acquiring)
-        self._spass_bgs = [dict() for _ in range(len(self.bpms))]
-        ants = {'A': [], 'B': [], 'C': [], 'D': []}
-        bgs = [_dcopy(ants) for _ in range(len(self.bpms))]
-        # Acquire the samples
-        for _ in range(self._smooth_npts):
-            for i, bpm in enumerate(self.bpms):
-                bgs[i]['A'].append(bpm.arraya)
-                bgs[i]['B'].append(bpm.arrayb)
-                bgs[i]['C'].append(bpm.arrayc)
-                bgs[i]['D'].append(bpm.arrayd)
-            _time.sleep(1/self._acqrate)
-        # Make the smoothing
-        try:
-            for i, bpm in enumerate(self.bpms):
-                for k, val in bgs[i].items():
-                    if self._smooth_meth == self._csorb.SmoothMeth.Average:
-                        bgs[i][k] = _np.mean(val, axis=0)
-                    else:
-                        bgs[i][k] = _np.median(val, axis=0)
-                    if not _np.all(_np.isfinite(bgs[i][k])):
-                        raise ValueError('there was some nans or infs.')
-            self._spass_bgs = bgs
-            self.run_callbacks(
-                'SPassBgSts-Mon', self._csorb.SPassBgSts.Acquired)
-        except (ValueError, TypeError) as err:
-            msg = 'ERR: SPassBg Acq ' + str(err)
-            self._update_log(msg)
-            _log.error(msg[5:])
-            self.run_callbacks('SPassBgSts-Mon', self._csorb.SPassBgSts.Empty)
-
-    def set_spass_usebg(self, val):
-        """."""
-        self._spass_usebg = int(val)
-        return True
-
     def set_spass_average(self, val):
         """."""
-        if self._ring_extension != 1 and val != 1:
-            msg = 'ERR: Cannot set SPassAvgNrTurns > 1 when RingSize > 1.'
-            self._update_log(msg)
-            _log.warning(msg[5:])
-            return False
         val = int(val) if val > 1 else 1
         with self._lock_raw_orbs:
             self._spass_average = val
@@ -546,7 +399,7 @@ class EpicsOrbit(BaseOrbit):
         self._update_log(msg)
         _log.info(msg)
         orb = _np.array(orb, dtype=float)
-        nrb = self._csorb.nr_bpms * self._ring_extension
+        nrb = self._csorb.nr_bpms
         if orb.size % self._csorb.nr_bpms:
             msg = 'ERR: Wrong RefOrb Size.'
             self._update_log(msg)
@@ -566,44 +419,16 @@ class EpicsOrbit(BaseOrbit):
         self.run_callbacks('RefOrb'+plane+'-RB', orb[:nrb])
         return True
 
-    def set_orbit_acq_rate(self, value):
-        """."""
-        if self.is_trigmode() and value > self._csorb.MAX_TRIGMODE_RATE:
-            msg = 'ERR: In triggered mode cannot set rate > {:d}.'.format(
-                self._csorb.MAX_TRIGMODE_RATE)
-            self._update_log(msg)
-            _log.error(msg[5:])
-            return False
-        elif self.is_sloworb() and value < self._csorb.MIN_SLOWORB_RATE:
-            msg = 'ERR: In SlowOrb cannot set rate < {:d}.'.format(
-                self._csorb.MIN_SLOWORB_RATE)
-            self._update_log(msg)
-            _log.error(msg[5:])
-            return False
-        self._acqrate = value
-        self._orbit_thread.interval = 1/value
-        self.run_callbacks('OrbAcqRate-RB', value)
-        return True
-
     def set_orbit_mode(self, value):
         """."""
-        bo1 = self.is_trigmode()
-        bo2 = not self.is_trigmode(value)
         omode = self._mode
-        if not bo2:
-            acqrate = self._csorb.MAX_TRIGMODE_RATE
-            dic = {'lolim': 0.01, 'hilim': acqrate}
-        else:
-            acqrate = self._oldacqrate
-            dic = {'lolim': self._csorb.MIN_SLOWORB_RATE, 'hilim': 100}
-        self.run_callbacks('OrbAcqRate-SP', acqrate, **dic)
-        self.run_callbacks('OrbAcqRate-RB', acqrate, **dic)
+        acqrate = self._csorb.ACQRATE_SLOWORB
+        if self.is_trigmode(value):
+            acqrate = self._csorb.ACQRATE_TRIGMODE
 
         with self._lock_raw_orbs:
             self._mode = value
-            if bo1 == bo2:
-                self._oldacqrate = self._acqrate
-                self.set_orbit_acq_rate(acqrate)
+            self._orbit_thread.interval = 1/acqrate
             self._reset_orbs()
         Thread(
             target=self._prepare_mode,
@@ -626,15 +451,14 @@ class EpicsOrbit(BaseOrbit):
             self.acq_config_bpms()
             return True
 
-        points = self._ring_extension
         if self.is_singlepass():
             chan = self._csorb.TrigAcqChan.ADCSwp
             rep = self._csorb.TrigAcqRepeat.Repetitive
-            points *= self._spass_average * self.bpms[0].tbtrate
+            points = self._spass_average * self.bpms[0].tbtrate
         elif self.is_multiturn():
             chan = self._csorb.TrigAcqChan.TbT
             rep = self._csorb.TrigAcqRepeat.Repetitive
-            points *= self._mturndownsample
+            points = self._mturndownsample
 
         if self._mode != oldmode:
             self.run_callbacks('TrigAcqChan-Sel', chan)
@@ -685,10 +509,32 @@ class EpicsOrbit(BaseOrbit):
                 self.timing.configure()
             elif self.is_sloworb():
                 bpm.switching_mode = _csbpm.SwModes.switching
-        Thread(target=self._synchronize_bpms, daemon=True).start()
+        self.sync_bpms(None)
         return True
 
+    def sync_bpms(self, *args):
+        """Synchronize BPMs."""
+        _ = args
+
+        msg = 'Received sync BPMs command...'
+        self._update_log(msg)
+        _log.info(msg)
+
+        if self._thread_sync is not None and \
+                self._thread_sync.is_alive():
+            msg = 'Waiting for previous sync to end...'
+            self._update_log(msg)
+            _log.info(msg)
+            self._thread_sync.join()
+
+        self._thread_sync = Thread(
+            target=self._synchronize_bpms, daemon=True)
+        self._thread_sync.start()
+
     def _synchronize_bpms(self):
+        msg = 'Syncing BPMs...'
+        self._update_log(msg)
+        _log.info(msg)
         for bpm in self._get_used_bpms():
             bpm.tbt_sync_enbl = _csbpm.EnbldDsbld.enabled
             bpm.fofb_sync_enbl = _csbpm.EnbldDsbld.enabled
@@ -703,8 +549,15 @@ class EpicsOrbit(BaseOrbit):
 
         if self.acc == 'SI' and self.sofb.fofb.connected:
             _time.sleep(0.2)
+            msg = 'Syncing FOFB Net...'
+            self._update_log(msg)
+            _log.info(msg)
             self.sofb.fofb.cmd_fofbctrl_syncnet()
 
+        msg = '...done!'
+        self._update_log(msg)
+        _log.info(msg)
+
     def set_trig_acq_control(self, value):
         """."""
         acqctrl = self._csorb.TrigAcqCtrl
@@ -738,20 +591,6 @@ class EpicsOrbit(BaseOrbit):
         self._update_time_vector(channel=val)
         return True
 
-    def set_trig_acq_trigger(self, value):
-        """."""
-        val = _csbpm.AcqTrigTyp.Data
-        if value == self._csorb.TrigAcqTrig.External:
-            val = _csbpm.AcqTrigTyp.External
-
-        mask = self._get_mask()
-        for i, bpm in enumerate(self.bpms):
-            bpm.put_enable = mask[i]
-            bpm.acq_trigger = val
-
-        self.run_callbacks('TrigAcqTrigger-Sts', value)
-        return True
-
     def set_trig_acq_repeat(self, value):
         """."""
         mask = self._get_mask()
@@ -762,58 +601,6 @@ class EpicsOrbit(BaseOrbit):
         self.run_callbacks('TrigAcqRepeat-Sts', value)
         return True
 
-    def set_trig_acq_datachan(self, value):
-        """."""
-        try:
-            val = self._csorb.TrigAcqDataChan._fields[value]
-            val = _csbpm.AcqChan._fields.index(val)
-        except (IndexError, ValueError):
-            return False
-
-        mask = self._get_mask()
-        for i, bpm in enumerate(self.bpms):
-            bpm.put_enable = mask[i]
-            bpm.acq_trig_datatype = val
-
-        self.run_callbacks('TrigDataChan-Sts', value)
-        return True
-
-    def set_trig_acq_datasel(self, value):
-        """."""
-        mask = self._get_mask()
-        for i, bpm in enumerate(self.bpms):
-            bpm.put_enable = mask[i]
-            bpm.acq_trig_datasel = value
-        self.run_callbacks('TrigDataSel-Sts', value)
-        return True
-
-    def set_trig_acq_datathres(self, value):
-        """."""
-        mask = self._get_mask()
-        for i, bpm in enumerate(self.bpms):
-            bpm.put_enable = mask[i]
-            bpm.acq_trig_datathres = value
-        self.run_callbacks('TrigDataThres-RB', value)
-        return True
-
-    def set_trig_acq_datahyst(self, value):
-        """."""
-        mask = self._get_mask()
-        for i, bpm in enumerate(self.bpms):
-            bpm.put_enable = mask[i]
-            bpm.acq_trig_datahyst = value
-        self.run_callbacks('TrigDataHyst-RB', value)
-        return True
-
-    def set_trig_acq_datapol(self, value):
-        """."""
-        mask = self._get_mask()
-        for i, bpm in enumerate(self.bpms):
-            bpm.put_enable = mask[i]
-            bpm.acq_trig_datapol = value
-        self.run_callbacks('TrigDataPol-Sts', value)
-        return True
-
     def set_acq_nrsamples(self, val, ispost=True):
         """."""
         val = int(val) if val > 0 else 0
@@ -863,11 +650,6 @@ class EpicsOrbit(BaseOrbit):
 
     def set_mturndownsample(self, val):
         """."""
-        if self._ring_extension != 1 and val != 1:
-            msg = 'ERR: Cannot set DownSample > 1 when RingSize > 1.'
-            self._update_log(msg)
-            _log.warning(msg[5:])
-            return False
         val = int(val) if val > 1 else 1
         val = val if val < 1000 else 1000
         with self._lock_raw_orbs:
@@ -905,7 +687,7 @@ class EpicsOrbit(BaseOrbit):
             dtime = self.bpms[0].fofbperiod
         else:
             dtime = self.bpms[0].tbtperiod
-        mult = self._mturndownsample * self._ring_extension
+        mult = self._mturndownsample
         dtime *= mult
         nrptpst = self.acqtrignrsamples // mult
         offset = self._acqtrignrsamplespre / mult
@@ -950,12 +732,18 @@ class EpicsOrbit(BaseOrbit):
 
     def _reset_orbs(self):
         """."""
-        self.raw_orbs = {'X': [], 'Y': []}
-        self.smooth_orb = {'X': None, 'Y': None}
-        self.raw_sporbs = {'X': [], 'Y': [], 'Sum': []}
-        self.smooth_sporb = {'X': None, 'Y': None, 'Sum': None}
-        self.raw_mtorbs = {'X': [], 'Y': [], 'Sum': []}
-        self.smooth_mtorb = {'X': None, 'Y': None, 'Sum': None}
+        raw = self.raw_orbs
+        smt = self.smooth_orb
+        raw['X'], raw['Y'] = [], []
+        smt['X'], smt['Y'] = None, None
+        raw = self.raw_sporbs
+        smt = self.smooth_sporb
+        raw['X'], raw['Y'], raw['Sum'] = [], [], []
+        smt['X'], smt['Y'], smt['Sum'] = None, None, None
+        raw = self.raw_mtorbs
+        smt = self.smooth_mtorb
+        raw['X'], raw['Y'], raw['Sum'] = [], [], []
+        smt['X'], smt['Y'], smt['Sum'] = None, None, None
         self.run_callbacks('BufferCount-Mon', 0)
 
     def _update_orbits(self):
@@ -985,9 +773,6 @@ class EpicsOrbit(BaseOrbit):
         nany = _np.isnan(posy)
         posx[nanx] = self.ref_orbs['X'][nanx]
         posy[nany] = self.ref_orbs['Y'][nany]
-        if self._ring_extension > 1:
-            posx = _np.tile(posx, (self._ring_extension, ))
-            posy = _np.tile(posy, (self._ring_extension, ))
         orbs = {'X': posx, 'Y': posy}
 
         for plane in ('X', 'Y'):
@@ -1001,7 +786,7 @@ class EpicsOrbit(BaseOrbit):
                     orb = _np.mean(raws[plane], axis=0)
                 else:
                     orb = _np.median(raws[plane], axis=0)
-            self.smooth_orb[plane] = orb
+                self.smooth_orb[plane] = orb
         self.new_orbit.set()
 
         self._sloworb_timeout += nok
@@ -1035,21 +820,18 @@ class EpicsOrbit(BaseOrbit):
 
     def _update_multiturn_orbits(self):
         """."""
-        if self._ring_extension != 1 and self._mturndownsample != 1:
-            return
         orbs = {'X': [], 'Y': [], 'Sum': []}
         with self._lock_raw_orbs:  # I need the lock here to ensure consistency
             samp = self.acqtrignrsamples
             down = self._mturndownsample
-            ringsz = self._ring_extension
-            samp -= samp % (ringsz*down)
+            samp -= samp % down
             if samp < 1:
                 msg = 'ERR: Actual nr_samples in MTurn orb calc. is < 1.'
                 self._update_log(msg)
                 _log.error(msg[5:])
                 return
             samp *= self._acqtrignrshots
-            orbsz = self._csorb.nr_bpms * ringsz
+            orbsz = self._csorb.nr_bpms
             nr_pts = self._smooth_npts
             for i, bpm in enumerate(self.bpms):
                 pos = bpm.mtposx
@@ -1104,7 +886,7 @@ class EpicsOrbit(BaseOrbit):
                 'MTurnIdx' + name + '-Mon', orb[idx, :].ravel())
             if pln == 'Sum':
                 continue
-            nrb = self._ring_extension * self._csorb.nr_bpms
+            nrb = self._csorb.nr_bpms
             dorb = orb[idx, :].ravel() - self.ref_orbs[pln][:nrb]
             self.run_callbacks(f'DeltaOrb{pln:s}Avg-Mon', _bn.nanmean(dorb))
             self.run_callbacks(f'DeltaOrb{pln:s}Std-Mon', _bn.nanstd(dorb))
@@ -1113,27 +895,18 @@ class EpicsOrbit(BaseOrbit):
 
     def _update_singlepass_orbits(self):
         """."""
-        if self._ring_extension != 1 and self._spass_average != 1:
-            return
         orbs = {'X': [], 'Y': [], 'Sum': []}
-        ringsz = self._ring_extension
         down = self._spass_average
-        use_bg = self._spass_usebg == self._csorb.SPassUseBg.Using
-        use_bg &= bool(self._spass_bgs[-1])  # check if there is a BG saved
-        pvv = self._csorb.SPassUseBg
-        self.run_callbacks(
-            'SPassUseBg-Sts', pvv.Using if use_bg else pvv.NotUsing)
         with self._lock_raw_orbs:  # I need the lock here to assure consistency
             dic = {
                 'maskbeg': self._spass_mask[0],
                 'maskend': self._spass_mask[1],
-                'nturns': ringsz * down}
+                'nturns': down}
             nr_pts = self._smooth_npts
             for i, bpm in enumerate(self.bpms):
                 dic.update({
                     'refx': self.ref_orbs['X'][i],
-                    'refy': self.ref_orbs['Y'][i],
-                    'bg': self._spass_bgs[i] if use_bg else dict()})
+                    'refy': self.ref_orbs['Y'][i]})
                 orbx, orby, summ = bpm.calc_sp_multiturn_pos(**dic)
                 orbs['X'].append(orbx)
                 orbs['Y'].append(orby)
@@ -1171,12 +944,8 @@ class EpicsOrbit(BaseOrbit):
         status = _util.update_bit(status, bit_pos=1, bit_val=not tim_conf)
 
         bpms = self._get_used_bpms()
-        if self._mode == self._csorb.SOFBMode.Offline:
-            bpm_conn = True
-            bpm_stt = True
-        else:
-            bpm_conn = all(bpm.connected for bpm in bpms)
-            bpm_stt = all(bpm.state for bpm in bpms)
+        bpm_conn = all(bpm.connected for bpm in bpms)
+        bpm_stt = all(bpm.state for bpm in bpms)
         status = _util.update_bit(v=status, bit_pos=2, bit_val=not bpm_conn)
         status = _util.update_bit(v=status, bit_pos=3, bit_val=not bpm_stt)
 
@@ -1195,7 +964,7 @@ class EpicsOrbit(BaseOrbit):
     def _update_bpmoffsets(self):
         """."""
         nrb = self._csorb.nr_bpms
-        orbx = _np.zeros(nrb * self._ring_extension, dtype=float)
+        orbx = _np.zeros(nrb, dtype=float)
         orby = orbx.copy()
         for i, bpm in enumerate(self.bpms):
             orbx[i::nrb] = bpm.offsetx or 0.0
